@@ -1,6 +1,6 @@
 """resport: Research portfolio site generator."""
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 import os
 import shutil
@@ -587,6 +587,9 @@ def main():
     global doctype
     doctype = args.doctype
 
+    if not os.path.exists('_build'):
+        os.makedirs('_build')
+
     sources = []
     if args.source in {'.'}:
         for single_source in glob.glob('*'):
@@ -603,4 +606,4 @@ def main():
 
     # update _site directory by copying over from _assets
     from dirsync import sync
-    sync('_assets/', '_site', 'sync')
\ No newline at end of file
+    sync('_assets/', '_site', 'sync')
